@@ -93,6 +93,8 @@ pub struct Builder<'fbb> {
     nodes_coords: Vec<Coord>,
     // Every node of a given traversal
     nodes_of_traversal: Vec<Vec<usize>>,
+    // Id of every node
+    nodes_ids: Vec<String>,
 
     // Final objects that will be in the binary file.
     nodes: Vec<WIPOffset<Node<'fbb>>>,
@@ -140,6 +142,7 @@ impl<'fbb> Builder<'fbb> {
         };
 
         self.nodes_coords.push(coord);
+        self.nodes_ids.push(id.to_owned());
         self.nodes.push(Node::create(&mut self.fbb, &args));
         self.nodes.len() - 1
     }
@@ -295,7 +298,7 @@ impl<'fbb> Builder<'fbb> {
                 AnchorPosition::Geographical(coord) => {
                     let projected = curve
                         .project(coord.into())
-                        .expect("could not projets anchor");
+                        .expect("could not project anchor");
                     let geometry = lrs_generated::Point::new(
                         projected.projected_coords.x(),
                         projected.projected_coords.y(),
@@ -479,7 +482,7 @@ impl<'fbb> Builder<'fbb> {
     pub fn euclidean_distance(&self, lrm_index_a: usize, lrm_index_b: usize) -> f64 {
         let a = &self.temp_traversal[lrm_index_a].curve.geom;
         let b = &self.temp_traversal[lrm_index_b].curve.geom;
-        geo::Euclidean::distance(a, b)
+        geo::Euclidean.distance(a, b)
     }
 
     /// Returns the position along the curve of the traversal
@@ -503,6 +506,11 @@ impl<'fbb> Builder<'fbb> {
         self.nodes_coords[node_index]
     }
 
+    /// Returns the identifier of a node
+    pub fn get_node_id(&self, node_index: usize) -> String {
+        self.nodes_ids[node_index].clone()
+    }
+
     /// Orient the traversal according to two points
     ///
     /// In the end, the first coordinate must be closer to the beginning than the second
@@ -633,6 +641,9 @@ mod tests {
         };
         b.add_lrm("lrm", traversal, &[aol, aol2], properties!());
 
+        b.add_node("a", coord! {x:0., y:1.}, properties!("source" => "test"));
+        b.add_node("b", coord! {x:1., y:1.}, properties!());
+
         let lrs = b.build_lrs(properties!()).unwrap();
         let lrm = lrs
             .resolve(
@@ -645,6 +656,12 @@ mod tests {
             .unwrap();
         assert_relative_eq!(lrm.x(), 0.);
         assert_relative_eq!(lrm.y(), 0.);
+
+        assert_eq!(lrs.lrs.nodes.len(), 2);
+        assert_eq!(lrs.lrs.nodes[0].properties["source"], "test");
+
+        assert_eq!(lrs.lrs.segments.len(), 2);
+        assert_eq!(lrs.lrs.segments[0].id, "s1");
     }
 
     #[test]
